@@ -15,17 +15,15 @@
     You should have received a copy of the GNU General Public License
  */
 
-pub mod xbku_enums;
 //mod xbku_downloader;
-pub mod xbku_formatter;
+pub mod xbku_enums;
+pub mod generic_enums;
 //mod xbku_structs;
 //mod xbku_platforms;
 //mod xbku_error_handling;
 
-/*
+
 pub mod libxbku_common{
-    
 
 
 }
-*/
\ No newline at end of file
